@@ -5,12 +5,16 @@ describe 'aodh::db' do
   shared_examples 'aodh::db' do
 
     context 'with default parameters' do
-      it { is_expected.to contain_aodh_config('database/db_max_retries').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_aodh_config('database/connection').with_value('sqlite:////var/lib/aodh/aodh.sqlite') }
-      it { is_expected.to contain_aodh_config('database/idle_timeout').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_aodh_config('database/min_pool_size').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_aodh_config('database/max_retries').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_aodh_config('database/retry_interval').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_oslo__db('aodh_config').with(
+        :db_max_retries => '<SERVICE DEFAULT>',
+        :connection     => 'sqlite:////var/lib/aodh/aodh.sqlite',
+        :idle_timeout   => '<SERVICE DEFAULT>',
+        :min_pool_size  => '<SERVICE DEFAULT>',
+        :max_pool_size  => '<SERVICE DEFAULT>',
+        :max_retries    => '<SERVICE DEFAULT>',
+        :retry_interval => '<SERVICE DEFAULT>',
+        :max_overflow   => '<SERVICE DEFAULT>',
+      )}
 
     end
 
@@ -20,22 +24,28 @@ describe 'aodh::db' do
           :database_connection     => 'mysql+pymysql://aodh:aodh@localhost/aodh',
           :database_idle_timeout   => '3601',
           :database_min_pool_size  => '2',
+          :database_max_pool_size  => '11',
           :database_max_retries    => '11',
           :database_retry_interval => '11',
+          :database_max_overflow   => '21',
         }
       end
-      it { is_expected.to contain_aodh_config('database/db_max_retries').with_value('-1') }
-      it { is_expected.to contain_aodh_config('database/connection').with_value('mysql+pymysql://aodh:aodh@localhost/aodh').with_secret(true) }
-      it { is_expected.to contain_aodh_config('database/idle_timeout').with_value('3601') }
-      it { is_expected.to contain_aodh_config('database/min_pool_size').with_value('2') }
-      it { is_expected.to contain_aodh_config('database/max_retries').with_value('11') }
-      it { is_expected.to contain_aodh_config('database/retry_interval').with_value('11') }
+      it { is_expected.to contain_oslo__db('aodh_config').with(
+        :db_max_retries => '-1',
+        :connection     => 'mysql+pymysql://aodh:aodh@localhost/aodh',
+        :idle_timeout   => '3601',
+        :min_pool_size  => '2',
+        :max_pool_size  => '11',
+        :max_retries    => '11',
+        :retry_interval => '11',
+        :max_overflow   => '21',
+      )}
 
     end
 
     context 'with postgresql backend' do
       let :params do
-        { :database_connection     => 'postgresql://localhost:1234/aodh', }
+        { :database_connection => 'postgresql://localhost:1234/aodh', }
       end
 
       it 'install the proper backend package' do
@@ -46,7 +56,7 @@ describe 'aodh::db' do
 
     context 'with MySQL-python library as backend package' do
       let :params do
-        { :database_connection     => 'mysql://aodh:aodh@localhost/aodh', }
+        { :database_connection => 'mysql://aodh:aodh@localhost/aodh', }
       end
 
       it { is_expected.to contain_package('python-mysqldb').with(:ensure => 'present') }
@@ -58,20 +68,21 @@ describe 'aodh::db' do
       end
 
       it 'installs python-mongodb package' do
-        is_expected.to contain_package('db_backend_package').with(
+        is_expected.to contain_package('python-pymongo').with(
           :ensure => 'present',
           :name   => 'python-pymongo',
           :tag    => 'openstack'
         )
-        is_expected.to contain_aodh_config('database/connection').with_value('mongodb://localhost:1234/aodh')
-        is_expected.to contain_aodh_config('database/connection').with_value( params[:database_connection] ).with_secret(true)
+        is_expected.to contain_oslo__db('aodh_config').with(
+          :connection => 'mongodb://localhost:1234/aodh',
+        )
       end
 
     end
 
     context 'with incorrect database_connection string' do
       let :params do
-        { :database_connection     => 'redis://aodh:aodh@localhost/aodh', }
+        { :database_connection => 'redis://aodh:aodh@localhost/aodh', }
       end
 
       it_raises 'a Puppet::Error', /validate_re/
@@ -79,7 +90,7 @@ describe 'aodh::db' do
 
     context 'with incorrect pymysql database_connection string' do
       let :params do
-        { :database_connection     => 'foo+pymysql://aodh:aodh@localhost/aodh', }
+        { :database_connection => 'foo+pymysql://aodh:aodh@localhost/aodh', }
       end
 
       it_raises 'a Puppet::Error', /validate_re/
@@ -89,11 +100,11 @@ describe 'aodh::db' do
   shared_examples_for 'aodh::db on Debian' do
     context 'with sqlite backend' do
       let :params do
-        { :database_connection     => 'sqlite:///var/lib/aodh/aodh.sqlite', }
+        { :database_connection => 'sqlite:///var/lib/aodh/aodh.sqlite', }
       end
 
       it 'install the proper backend package' do
-        is_expected.to contain_package('db_backend_package').with(
+        is_expected.to contain_package('python-pysqlite2').with(
           :ensure => 'present',
           :name   => 'python-pysqlite2',
           :tag    => 'openstack'
@@ -103,11 +114,11 @@ describe 'aodh::db' do
 
     context 'using pymysql driver' do
       let :params do
-        { :database_connection     => 'mysql+pymysql://aodh:aodh@localhost/aodh', }
+        { :database_connection => 'mysql+pymysql://aodh:aodh@localhost/aodh', }
       end
 
       it 'install the proper backend package' do
-        is_expected.to contain_package('db_backend_package').with(
+        is_expected.to contain_package('python-pymysql').with(
           :ensure => 'present',
           :name   => 'python-pymysql',
           :tag    => 'openstack'
@@ -119,10 +130,8 @@ describe 'aodh::db' do
   shared_examples_for 'aodh::db on RedHat' do
     context 'using pymysql driver' do
       let :params do
-        { :database_connection     => 'mysql+pymysql://aodh:aodh@localhost/aodh', }
+        { :database_connection => 'mysql+pymysql://aodh:aodh@localhost/aodh', }
       end
-
-      it { is_expected.not_to contain_package('db_backend_package') }
     end
   end
 
