@@ -4,13 +4,21 @@ describe 'aodh::db::sync' do
 
   shared_examples_for 'aodh-dbsync' do
 
+    it { is_expected.to contain_class('aodh::deps') }
+
     it 'runs aodh-db-sync' do
       is_expected.to contain_exec('aodh-db-sync').with(
         :command     => 'aodh-dbsync --config-file /etc/aodh/aodh.conf',
         :path        => '/usr/bin',
         :refreshonly => 'true',
         :user        => 'aodh',
-        :logoutput   => 'on_failure'
+        :try_sleep   => 5,
+        :tries       => 10,
+        :logoutput   => 'on_failure',
+        :subscribe   => ['Anchor[aodh::install::end]',
+                         'Anchor[aodh::config::end]',
+                         'Anchor[aodh::dbsync::begin]'],
+        :notify      => 'Anchor[aodh::dbsync::end]',
       )
     end
 
@@ -22,7 +30,7 @@ describe 'aodh::db::sync' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
+          :os_workers     => 8,
           :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
